| Title: | Shiny LLM-Enabled Causal Assumption Analyzer Using Dagwood |
|---|---|
| Description: | Shiny app that converts a free-form causal inference scenario into a directed acyclic graph using a LLM, runs Dagwood to extract assumptions and branch DAGs, and evaluates each assumption using the LLM. |
| Authors: | Steven Baldasty [aut, cre] |
| Maintainer: | Steven Baldasty <[email protected]> |
| License: | file LICENSE |
| Version: | 0.2.0 |
| Built: | 2026-05-13 22:20:03 UTC |
| Source: | https://github.com/sbaldasty/agent-dagwood |
Starts the packaged Shiny app for scenario-to-DAG analysis and assumption evaluation. Requires the environment variable GEMINI_API_KEY to be set.
run_app(launch.browser = interactive(), ...)run_app(launch.browser = interactive(), ...)
launch.browser |
Logical. Whether to open a browser automatically. |
... |
Additional arguments passed to |
Invisibly returns the running Shiny app object.